# BTB: Bayesian Tuning and Bandits
Smart selection of hyperparameters
* selection/ defines Selectors: classes for choosing from a set of discrete
  options with multi-armed bandits
* tuning/ defines Tuners: classes with a fit/predict/propose interface for
  suggesting sets of hyperparameters

